@@ -47,28 +47,28 @@
  * Users Notice.
  */
 
+#include <assert.h>
+#include <cuda_runtime.h>
+#include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <math.h>
-#include <assert.h>
-#include <cuda_runtime.h>
 
 #include "cudss.h"
 
 #ifdef USE_MPI
-#  include "mpi.h"
-#  ifdef USE_NCCL
-#    include "nccl.h"
-#  endif
-#  if !defined(USE_OPENMPI) && !defined(USE_NCCL)
-#    error "With USE_MPI, either USE_OPENMPI or USE_NCCL must be defined"
-#  endif
-#  if defined(USE_OPENMPI) && defined(USE_NCCL)
-#    error "With USE_MPI, exactly one of USE_OPENMPI and USE_NCCL must be defined"
-#  endif
+#include "mpi.h"
+#ifdef USE_NCCL
+#include "nccl.h"
+#endif
+#if !defined(USE_OPENMPI) && !defined(USE_NCCL)
+#error "With USE_MPI, either USE_OPENMPI or USE_NCCL must be defined"
+#endif
+#if defined(USE_OPENMPI) && defined(USE_NCCL)
+#error "With USE_MPI, exactly one of USE_OPENMPI and USE_NCCL must be defined"
+#endif
 #else
-#  error "This example needs to be compiled with MPI (and optionally with NCCL as well)"
+#error "This example needs to be compiled with MPI (and optionally with NCCL as well)"
 #endif
 
 /*
@@ -86,70 +86,75 @@
     Note: The MGMN mode is intended to be used for solving large systems.
 */
 
-#define CUDSS_EXAMPLE_FREE \
-    do { \
-        free(csr_offsets_h); \
-        free(csr_columns_h); \
-        free(csr_values_h); \
-        free(x_values_h); \
-        free(b_values_h); \
-        cudaFree(csr_offsets_d); \
-        cudaFree(csr_columns_d); \
-        cudaFree(csr_values_d); \
-        cudaFree(x_values_d); \
-        cudaFree(b_values_d); \
-    } while(0);
+#define CUDSS_EXAMPLE_FREE                                                               \
+    do {                                                                                 \
+        free(csr_offsets_h);                                                             \
+        free(csr_columns_h);                                                             \
+        free(csr_values_h);                                                              \
+        free(x_values_h);                                                                \
+        free(b_values_h);                                                                \
+        cudaFree(csr_offsets_d);                                                         \
+        cudaFree(csr_columns_d);                                                         \
+        cudaFree(csr_values_d);                                                          \
+        cudaFree(x_values_d);                                                            \
+        cudaFree(b_values_d);                                                            \
+    } while (0);
 
-#define CUDA_CALL_AND_CHECK(call, msg) \
-    do { \
-        cuda_error = call; \
-        if (cuda_error != cudaSuccess) { \
-            printf("Example FAILED: CUDA API returned error = %d, details: " #msg "\n", cuda_error); \
-            return -3; \
-        } \
-    } while(0);
+#define CUDA_CALL_AND_CHECK(call, msg)                                                   \
+    do {                                                                                 \
+        cuda_error = call;                                                               \
+        if (cuda_error != cudaSuccess) {                                                 \
+            printf("Example FAILED: CUDA API returned error = %d, details: " #msg "\n",  \
+                   cuda_error);                                                          \
+            return -3;                                                                   \
+        }                                                                                \
+    } while (0);
 
 #ifdef USE_MPI
-#  define MPI_CALL_AND_CHECK(call, msg) \
-    do { \
-        mpi_error = call; \
-        if (mpi_error != 0) { \
-            printf("Example FAILED: MPI call returned error = %d, details: " #msg "\n", mpi_error); \
-            return -4; \
-        } \
-    } while(0);
-#  ifdef USE_NCCL
-#    define NCCL_CALL_AND_CHECK(call, msg) \
-    do { \
-        nccl_result = call; \
-        if (nccl_result != ncclSuccess) { \
-            printf("Example FAILED: NCCL call returned error = %d, details: " #msg "\n", nccl_result); \
-            return -5; \
-        } \
-    } while(0);
-#  endif
+#define MPI_CALL_AND_CHECK(call, msg)                                                    \
+    do {                                                                                 \
+        mpi_error = call;                                                                \
+        if (mpi_error != 0) {                                                            \
+            printf("Example FAILED: MPI call returned error = %d, details: " #msg "\n",  \
+                   mpi_error);                                                           \
+            return -4;                                                                   \
+        }                                                                                \
+    } while (0);
+#ifdef USE_NCCL
+#define NCCL_CALL_AND_CHECK(call, msg)                                                   \
+    do {                                                                                 \
+        nccl_result = call;                                                              \
+        if (nccl_result != ncclSuccess) {                                                \
+            printf("Example FAILED: NCCL call returned error = %d, details: " #msg "\n", \
+                   nccl_result);                                                         \
+            return -5;                                                                   \
+        }                                                                                \
+    } while (0);
+#endif
 #endif
 
 
-#define CUDSS_CALL_AND_CHECK(call, status, msg) \
-    do { \
-        status = call; \
-        if (status != CUDSS_STATUS_SUCCESS) { \
-            printf("Example FAILED: CUDSS call ended unsuccessfully with status = %d, details: " #msg "\n", status); \
-            CUDSS_EXAMPLE_FREE; \
-            return -6; \
-        } \
-    } while(0);
+#define CUDSS_CALL_AND_CHECK(call, status, msg)                                          \
+    do {                                                                                 \
+        status = call;                                                                   \
+        if (status != CUDSS_STATUS_SUCCESS) {                                            \
+            printf("Example FAILED: CUDSS call ended unsuccessfully with status = %d, "  \
+                   "details: " #msg "\n",                                                \
+                   status);                                                              \
+            CUDSS_EXAMPLE_FREE;                                                          \
+            return -6;                                                                   \
+        }                                                                                \
+    } while (0);
 
 
-int main (int argc, char *argv[]) {
+int main(int argc, char *argv[]) {
     cudaError_t   cuda_error = cudaSuccess;
     cudssStatus_t status     = CUDSS_STATUS_SUCCESS;
 #ifdef USE_MPI
-    int           mpi_error  = 0;
-#  ifdef USE_NCCL
-    ncclResult_t  nccl_result = ncclSuccess;
-#  endif
+    int mpi_error = 0;
+#ifdef USE_NCCL
+    ncclResult_t nccl_result = ncclSuccess;
+#endif
 #endif
 
     /* Initializing the communication backend
@@ -203,27 +208,30 @@ int main (int argc, char *argv[]) {
     char comm_layer_libname[1024];
     if (argc > 2) {
         strcpy(comm_backend_name, argv[1]);
-        if (rank == 0) printf("Communication backend name is: %s\n", comm_backend_name);
+        if (rank == 0)
+            printf("Communication backend name is: %s\n", comm_backend_name);
         strcpy(comm_layer_libname, argv[2]);
         printf("Communication layer library name is: %s\n", comm_layer_libname);
         fflush(0);
     } else if (argc == 2) {
         strcpy(comm_backend_name, argv[1]);
-        if (rank == 0) printf("Communication backend name is: %s\n", comm_backend_name);
+        if (rank == 0)
+            printf("Communication backend name is: %s\n", comm_backend_name);
         if (rank == 0)
             printf("Since communication layer library name was not provided as input \n"
-                    "argument for the executable, the layer library name will be \n"
-                    "taken from CUDSS_COMM_LIB environment variable\n");
+                   "argument for the executable, the layer library name will be \n"
+                   "taken from CUDSS_COMM_LIB environment variable\n");
         fflush(0);
     } else {
         if (rank == 0) {
-            printf("Error: this example requires passing at least one argument:\n"
-                    "the communication backend name (openmpi or nccl)\n"
-                    "and, optionally, the second argument for the communication \n"
-                    "layer library (full name with the path)\n"
-                    "If the second argument is not present, the layer library name will be \n"
-                    "taken from CUDSS_COMM_LIB environment variable\n"
-                    "Note: backend should match the communication layer library\n");
+            printf(
+                "Error: this example requires passing at least one argument:\n"
+                "the communication backend name (openmpi or nccl)\n"
+                "and, optionally, the second argument for the communication \n"
+                "layer library (full name with the path)\n"
+                "If the second argument is not present, the layer library name will be \n"
+                "taken from CUDSS_COMM_LIB environment variable\n"
+                "Note: backend should match the communication layer library\n");
             fflush(0);
         }
 #ifdef USE_MPI
@@ -237,59 +245,61 @@ int main (int argc, char *argv[]) {
 #ifdef USE_MPI
     MPI_Comm *mpi_comm = NULL;
 
-    #if USE_OPENMPI
-    if (strcmp(comm_backend_name,"openmpi") == 0) {
-        mpi_comm = (MPI_Comm*) malloc(sizeof(MPI_Comm));
+#if USE_OPENMPI
+    if (strcmp(comm_backend_name, "openmpi") == 0) {
+        mpi_comm    = (MPI_Comm *)malloc(sizeof(MPI_Comm));
         mpi_comm[0] = MPI_COMM_WORLD;
     }
-    #endif
-    #if USE_NCCL
+#endif
+#if USE_NCCL
     ncclComm_t *nccl_comm = NULL;
-    if (strcmp(comm_backend_name,"nccl") == 0) {
-        nccl_comm = (ncclComm_t*) malloc(sizeof(ncclComm_t));
+    if (strcmp(comm_backend_name, "nccl") == 0) {
+        nccl_comm = (ncclComm_t *)malloc(sizeof(ncclComm_t));
         ncclUniqueId id;
         if (rank == 0) {
             NCCL_CALL_AND_CHECK(ncclGetUniqueId(&id), "ncclGetUniqueId");
         }
         MPI_CALL_AND_CHECK(MPI_Bcast(&id, sizeof(id), MPI_BYTE, 0, MPI_COMM_WORLD),
                            "MPI_Bcast for id");
-        NCCL_CALL_AND_CHECK(ncclCommInitRank(nccl_comm, size, id, rank), "ncclCommInitRank");
+        NCCL_CALL_AND_CHECK(ncclCommInitRank(nccl_comm, size, id, rank),
+                            "ncclCommInitRank");
     }
-    #endif
+#endif
 #endif
 
-    int n = 5;
-    int nnz = 8;
+    int n    = 5;
+    int nnz  = 8;
     int nrhs = 1;
 
-    int *csr_offsets_h = NULL;
-    int *csr_columns_h = NULL;
-    double *csr_values_h = NULL;
+    int    *csr_offsets_h = NULL;
+    int    *csr_columns_h = NULL;
+    double *csr_values_h  = NULL;
     double *x_values_h = NULL, *b_values_h = NULL;
 
-    int *csr_offsets_d = NULL;
-    int *csr_columns_d = NULL;
-    double *csr_values_d = NULL;
+    int    *csr_offsets_d = NULL;
+    int    *csr_columns_d = NULL;
+    double *csr_values_d  = NULL;
     double *x_values_d = NULL, *b_values_d = NULL;
 
     /* We only allocate host and device memory  for A,x and b for the root process */
     if (rank == 0) {
         /* Allocate host memory for the sparse input matrix A,
            right-hand side x and solution b*/
-        csr_offsets_h = (int*)malloc((n + 1) * sizeof(int));
-        csr_columns_h = (int*)malloc(nnz * sizeof(int));
-        csr_values_h = (double*)malloc(nnz * sizeof(double));
-        x_values_h = (double*)malloc(nrhs * n * sizeof(double));
-        b_values_h = (double*)malloc(nrhs * n * sizeof(double));
+        csr_offsets_h = (int *)malloc((n + 1) * sizeof(int));
+        csr_columns_h = (int *)malloc(nnz * sizeof(int));
+        csr_values_h  = (double *)malloc(nnz * sizeof(double));
+        x_values_h    = (double *)malloc(nrhs * n * sizeof(double));
+        b_values_h    = (double *)malloc(nrhs * n * sizeof(double));
 
-        if (!csr_offsets_h || ! csr_columns_h || !csr_values_h ||
-            !x_values_h || !b_values_h) {
-            printf("Error: host memory allocation failed\n");fflush(0);
+        if (!csr_offsets_h || !csr_columns_h || !csr_values_h || !x_values_h ||
+            !b_values_h) {
+            printf("Error: host memory allocation failed\n");
+            fflush(0);
             return -2;
         }
 
         /* Initialize host memory for A and b */
-        int i = 0;
+        int i              = 0;
         csr_offsets_h[i++] = 0;
         csr_offsets_h[i++] = 2;
         csr_offsets_h[i++] = 4;
@@ -297,23 +307,29 @@ int main (int argc, char *argv[]) {
         csr_offsets_h[i++] = 7;
         csr_offsets_h[i++] = 8;
 
-        i = 0;
-        csr_columns_h[i++] = 0; csr_columns_h[i++] = 2;
-        csr_columns_h[i++] = 1; csr_columns_h[i++] = 2;
-        csr_columns_h[i++] = 2; csr_columns_h[i++] = 4;
+        i                  = 0;
+        csr_columns_h[i++] = 0;
+        csr_columns_h[i++] = 2;
+        csr_columns_h[i++] = 1;
+        csr_columns_h[i++] = 2;
+        csr_columns_h[i++] = 2;
+        csr_columns_h[i++] = 4;
         csr_columns_h[i++] = 3;
         csr_columns_h[i++] = 4;
 
-        i = 0;
-        csr_values_h[i++] = 4.0; csr_values_h[i++] = 1.0;
-        csr_values_h[i++] = 3.0; csr_values_h[i++] = 2.0;
-        csr_values_h[i++] = 5.0; csr_values_h[i++] = 1.0;
+        i                 = 0;
+        csr_values_h[i++] = 4.0;
+        csr_values_h[i++] = 1.0;
+        csr_values_h[i++] = 3.0;
+        csr_values_h[i++] = 2.0;
+        csr_values_h[i++] = 5.0;
+        csr_values_h[i++] = 1.0;
         csr_values_h[i++] = 1.0;
         csr_values_h[i++] = 2.0;
 
         /* Note: Right-hand side b is initialized with values which correspond
         to the exact solution vector {1, 2, 3, 4, 5} */
-        i = 0;
+        i               = 0;
         b_values_h[i++] = 7.0;
         b_values_h[i++] = 12.0;
         b_values_h[i++] = 25.0;
@@ -333,14 +349,18 @@ int main (int argc, char *argv[]) {
                             "cudaMalloc for x_values");
 
         /* Copy host memory to device for A and b */
-        CUDA_CALL_AND_CHECK(cudaMemcpy(csr_offsets_d, csr_offsets_h, (n + 1) * sizeof(int),
-                            cudaMemcpyHostToDevice), "cudaMemcpy for csr_offsets");
+        CUDA_CALL_AND_CHECK(cudaMemcpy(csr_offsets_d, csr_offsets_h,
+                                       (n + 1) * sizeof(int), cudaMemcpyHostToDevice),
+                            "cudaMemcpy for csr_offsets");
         CUDA_CALL_AND_CHECK(cudaMemcpy(csr_columns_d, csr_columns_h, nnz * sizeof(int),
-                            cudaMemcpyHostToDevice), "cudaMemcpy for csr_columns");
+                                       cudaMemcpyHostToDevice),
+                            "cudaMemcpy for csr_columns");
         CUDA_CALL_AND_CHECK(cudaMemcpy(csr_values_d, csr_values_h, nnz * sizeof(double),
-                            cudaMemcpyHostToDevice), "cudaMemcpy for csr_values");
+                                       cudaMemcpyHostToDevice),
+                            "cudaMemcpy for csr_values");
         CUDA_CALL_AND_CHECK(cudaMemcpy(b_values_d, b_values_h, nrhs * n * sizeof(double),
-                            cudaMemcpyHostToDevice), "cudaMemcpy for b_values");
+                                       cudaMemcpyHostToDevice),
+                            "cudaMemcpy for b_values");
     }
 
     /* Create a CUDA stream */
@@ -363,7 +383,7 @@ int main (int argc, char *argv[]) {
 
     /* Creating cuDSS solver configuration and data objects */
     cudssConfig_t solverConfig;
-    cudssData_t solverData;
+    cudssData_t   solverData;
 
     CUDSS_CALL_AND_CHECK(cudssConfigCreate(&solverConfig), status, "cudssConfigCreate");
     CUDSS_CALL_AND_CHECK(cudssDataCreate(handle, &solverData), status, "cudssDataCreate");
@@ -374,78 +394,88 @@ int main (int argc, char *argv[]) {
     cudssMatrix_t x, b;
 
     int64_t nrows = n, ncols = n;
-    int ldb = ncols, ldx = nrows;
+    int     ldb = ncols, ldx = nrows;
     CUDSS_CALL_AND_CHECK(cudssMatrixCreateDn(&b, ncols, nrhs, ldb, b_values_d, CUDA_R_64F,
-                         CUDSS_LAYOUT_COL_MAJOR), status, "cudssMatrixCreateDn for b");
+                                             CUDSS_LAYOUT_COL_MAJOR),
+                         status, "cudssMatrixCreateDn for b");
     CUDSS_CALL_AND_CHECK(cudssMatrixCreateDn(&x, nrows, nrhs, ldx, x_values_d, CUDA_R_64F,
-                         CUDSS_LAYOUT_COL_MAJOR), status, "cudssMatrixCreateDn for x");
+                                             CUDSS_LAYOUT_COL_MAJOR),
+                         status, "cudssMatrixCreateDn for x");
 
     /* Create a matrix object for the sparse input matrix.
        Note: currently, matrix A must be fully present on the root process (rank = 0),
        and the rest of the processes should have correct shape of the matrix (but it is
        fine to have NULL pointers for the data arrays). */
-    cudssMatrix_t A;
-    cudssMatrixType_t mtype     = CUDSS_MTYPE_SPD;
+    cudssMatrix_t         A;
+    cudssMatrixType_t     mtype = CUDSS_MTYPE_SPD;
     cudssMatrixViewType_t mview = CUDSS_MVIEW_UPPER;
-    cudssIndexBase_t base       = CUDSS_BASE_ZERO;
+    cudssIndexBase_t      base  = CUDSS_BASE_ZERO;
     CUDSS_CALL_AND_CHECK(cudssMatrixCreateCsr(&A, nrows, ncols, nnz, csr_offsets_d, NULL,
-                         csr_columns_d, csr_values_d, CUDA_R_32I, CUDA_R_64F, mtype, mview,
-                         base), status, "cudssMatrixCreateCsr");
+                                              csr_columns_d, csr_values_d, CUDA_R_32I,
+                                              CUDA_R_64F, mtype, mview, base),
+                         status, "cudssMatrixCreateCsr");
 
     /* Setting communicator to be used by MGMN mode of cuDSS */
 #ifdef USE_MPI
-    #if USE_OPENMPI
-    if (strcmp(comm_backend_name,"openmpi") == 0) {
-        CUDSS_CALL_AND_CHECK(cudssDataSet(handle, solverData, CUDSS_DATA_COMM,
-                                          mpi_comm, sizeof(MPI_Comm*)),
-                                          status, "cudssDataSet for OpenMPI comm");
+#if USE_OPENMPI
+    if (strcmp(comm_backend_name, "openmpi") == 0) {
+        CUDSS_CALL_AND_CHECK(cudssDataSet(handle, solverData, CUDSS_DATA_COMM, mpi_comm,
+                                          sizeof(MPI_Comm *)),
+                             status, "cudssDataSet for OpenMPI comm");
     }
-    #endif
-    #if USE_NCCL
-    if (strcmp(comm_backend_name,"nccl") == 0) {
-        CUDSS_CALL_AND_CHECK(cudssDataSet(handle, solverData, CUDSS_DATA_COMM,
-                             nccl_comm, sizeof(ncclComm_t*)),
+#endif
+#if USE_NCCL
+    if (strcmp(comm_backend_name, "nccl") == 0) {
+        CUDSS_CALL_AND_CHECK(cudssDataSet(handle, solverData, CUDSS_DATA_COMM, nccl_comm,
+                                          sizeof(ncclComm_t *)),
                              status, "cudssDataSet for NCCL comm");
     }
-    #endif
+#endif
 #endif
 
     /* Symbolic factorization */
-    CUDSS_CALL_AND_CHECK(cudssExecute(handle, CUDSS_PHASE_ANALYSIS, solverConfig, solverData,
-                         A, x, b), status, "cudssExecute for analysis");
+    CUDSS_CALL_AND_CHECK(
+        cudssExecute(handle, CUDSS_PHASE_ANALYSIS, solverConfig, solverData, A, x, b),
+        status, "cudssExecute for analysis");
 
     /* Factorization */
     CUDSS_CALL_AND_CHECK(cudssExecute(handle, CUDSS_PHASE_FACTORIZATION, solverConfig,
-                         solverData, A, x, b), status, "cudssExecute for factor");
+                                      solverData, A, x, b),
+                         status, "cudssExecute for factor");
 
     /* Solving */
-    CUDSS_CALL_AND_CHECK(cudssExecute(handle, CUDSS_PHASE_SOLVE, solverConfig, solverData,
-                         A, x, b), status, "cudssExecute for solve");
+    CUDSS_CALL_AND_CHECK(
+        cudssExecute(handle, CUDSS_PHASE_SOLVE, solverConfig, solverData, A, x, b),
+        status, "cudssExecute for solve");
 
     /* Destroying opaque objects, matrix wrappers and the cuDSS library handle */
     CUDSS_CALL_AND_CHECK(cudssMatrixDestroy(A), status, "cudssMatrixDestroy for A");
     CUDSS_CALL_AND_CHECK(cudssMatrixDestroy(b), status, "cudssMatrixDestroy for b");
     CUDSS_CALL_AND_CHECK(cudssMatrixDestroy(x), status, "cudssMatrixDestroy for x");
-    CUDSS_CALL_AND_CHECK(cudssDataDestroy(handle, solverData), status, "cudssDataDestroy");
+    CUDSS_CALL_AND_CHECK(cudssDataDestroy(handle, solverData), status,
+                         "cudssDataDestroy");
     CUDSS_CALL_AND_CHECK(cudssConfigDestroy(solverConfig), status, "cudssConfigDestroy");
     CUDSS_CALL_AND_CHECK(cudssDestroy(handle), status, "cudssHandleDestroy");
 
     CUDA_CALL_AND_CHECK(cudaStreamSynchronize(stream), "cudaStreamSynchronize");
 
-    /* (optional) For the root process, print the solution and compare against the exact solution */
+    /* (optional) For the root process, print the solution and compare against the exact
+     * solution */
     int passed = 1;
     if (rank == 0) {
         CUDA_CALL_AND_CHECK(cudaMemcpy(x_values_h, x_values_d, nrhs * n * sizeof(double),
-                            cudaMemcpyDeviceToHost), "cudaMemcpy for x_values");
+                                       cudaMemcpyDeviceToHost),
+                            "cudaMemcpy for x_values");
 
         for (int i = 0; i < n; i++) {
-            printf("x[%d] = %1.4f expected %1.4f\n", i, x_values_h[i], double(i+1));
+            printf("x[%d] = %1.4f expected %1.4f\n", i, x_values_h[i], double(i + 1));
             if (fabs(x_values_h[i] - (i + 1)) > 2.e-15)
-            passed = 0;
+                passed = 0;
         }
     }
 
-    /* (optional) For the root process, print the solution and compare against the exact solution */
+    /* (optional) For the root process, print the solution and compare against the exact
+     * solution */
     if (rank == 0) {
         /* Release the data allocated on the user side */
 
@@ -454,11 +484,14 @@ int main (int argc, char *argv[]) {
 
     /* Deleting the memory allocated for the communicator */
 #if USE_MPI
-    if (mpi_comm != NULL) free(mpi_comm);
+    if (mpi_comm != NULL)
+        free(mpi_comm);
 #endif
 #if USE_NCCL
-    if (nccl_comm != NULL) NCCL_CALL_AND_CHECK(ncclCommDestroy(*nccl_comm),"ncclCommDestroy");
-    if (nccl_comm != NULL) free(nccl_comm);
+    if (nccl_comm != NULL)
+        NCCL_CALL_AND_CHECK(ncclCommDestroy(*nccl_comm), "ncclCommDestroy");
+    if (nccl_comm != NULL)
+        free(nccl_comm);
 #endif
 
     /* Cleanup for the communication backend
